@@ -37,6 +37,11 @@ use Hubzero\Filesystem\Entity;
 use Components\Projects\Models\Orm\Connection;
 use stdClass;
 use ZipArchive;
+use Filesystem;
+use Route;
+use Lang;
+use User;
+use Date;
 
 /**
  * Handles a file attachment
@@ -142,6 +147,7 @@ class File extends Base
 		$bundleName           = $versionParams->get('element' . $elementId . 'bundlename', $configs->title);
 		$configs->bundleTitle = $bundleName ? $bundleName : $configs->title;
 		$configs->bundleName  = $bundleName ? $bundleName . '.zip' : 'bundle.zip';
+		$configs->bundleOverwrite = $versionParams->get('bundleOverwrite', false);
 
 		// Allow rename?
 		$configs->allowRename = false;
@@ -193,7 +199,7 @@ class File extends Base
 		// Add inside bundles
 		if ($configs->multiZip == 1 && $attachments && count($attachments) > 1)
 		{
-			$filePath = $this->bundle($attachments, $configs, false);
+			$filePath = $this->bundle($attachments, $configs, $configs->bundleOverwrite);
 			$bPath    = $configs->pubBase . DS . 'bundles';
 			if (is_file($filePath))
 			{
@@ -411,7 +417,7 @@ class File extends Base
 				$html .= ' <span class="edititem">';
 				$html .= '<a href="index.php?option=com_publications&controller=items&task=editcontent&id=' . $pub->get('id') . '&el=' . $elementId . '&v=' . $pub->get('version_number') . '">';
 				$html .= Lang::txt('COM_PUBLICATIONS_EDIT');
-				$hmtl .= '</a>';
+				$html .= '</a>';
 				$html .= '</span>';
 			}
 			$html .= '</span>';
@@ -674,7 +680,7 @@ class File extends Base
 				$handle = fopen($hfile, 'w');
 				fwrite($handle, $md5hash);
 				fclose($handle);
-				chmod($hfile, 0644);
+				@chmod($hfile, 0644);
 
 				$pAttach->store();
 
@@ -1281,7 +1287,7 @@ class File extends Base
 			$handle = fopen($hfile, 'w');
 			fwrite($handle, $md5hash);
 			fclose($handle);
-			chmod($hfile, 0644);
+			@chmod($hfile, 0644);
 
 			$objPA->store();
 
